Documentation
¶
Index ¶
Constants ¶
const MaxOperatorsOnPage = 5
MaxOperatorsOnPage defines maximum limit on operators page.
Variables ¶
var ( // Error is an error class for operators service error. Error = errs.Class("operators") )
Functions ¶
This section is empty.
Types ¶
type Operator ¶
type Operator struct {
NodeID storj.NodeID `json:"nodeId"`
Email string `json:"email"`
Wallet string `json:"wallet"`
WalletFeatures []string `json:"walletFeatures"`
Undistributed int64 `json:"undistributed"`
}
Operator contains SNO payouts contact details and amount of undistributed payouts.
type Page ¶
type Page struct {
Operators []Operator `json:"operators"`
Offset int64 `json:"offset"`
Limit int64 `json:"limit"`
CurrentPage int64 `json:"currentPage"`
PageCount int64 `json:"pageCount"`
TotalCount int64 `json:"totalCount"`
}
Page holds operator page entity which is used to show listed page of operators.
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service exposes all operators related logic.
architecture: Service
func NewService ¶
NewService creates new instance of Service.
func (*Service) GetOperator ¶
GetOperator retrieves operator form node via rpc.
Click to show internal directories.
Click to hide internal directories.